============
Auto Watch
============
*watchdog + rsync完成自动同步小工具*

依赖
-------------
1. watchdog

安装方法
-----------
1. pip install autowatch

使用
--------------
1. 进入配置文件所在目录
2. autowatchme.pyw tricks.yaml
3. 会在当前目录生成autowatch.log日志文件，查看日志: tailf autowatch.log

trick.yaml配置实例
------------------

::

  python-path:
  - d:/linux/pyscript

  tricks:
  - tricks.ShellZCommandTrick:
      source_directory: D:\Workstation\blueking
      target: root@192.168.11.106:/root/workspace"

  - tricks.ShellZCommandTrick:
      source_directory: D:\Workstation\blueking\blueking_alarm
      target: root@192.168.11.106:/home/joe/workspace"

autowatch.log日志文件
--------------------------
::

  2015-04-09 00:14:59,780 [INFO] autowatch.cmd tricks.yaml
  2015-04-09 00:14:59,780 [INFO] autowatch.cmd D:\linux\pyscript
  2015-04-09 00:14:59,780 [INFO] autowatch.events PatternMatching: ['*tricks.yaml']
  2015-04-09 00:14:59,782 [INFO] autowatch.cmd Start AutoWatchYaml Success
  2015-04-09 00:15:31,500 [INFO] autowatch.events Start <YamlTrick(Thread-3, started daemon 13400)>
  2015-04-09 00:15:31,500 [INFO] autowatch.events YamlTrick: ['D:\\linux\\pyscript\\tricks.yaml']
